@@ -87,6 +87,25 @@ def save_to_file(data, url=None, filename=None):
     logger.info("saved to %s" % filename)
 
 
+def camel_to_snake(s):
+    """
+    Converts CamelCase/camelCase to snake_case
+    :param str s: string to be converted
+    :return: (str) snake_case version of s
+    """
+
+    return re.sub("((?!^)(?<!_)[A-Z][a-z]+|(?<=[a-z0-9])[A-Z])", r"_\1", s).lower()
+
+
+def snake_to_camel(s):
+    """
+    Converts snake_case_string to camelCaseString
+    :param str s: string to be converted
+    :return: (str) camelCase version of s
+    """
+    return re.sub("(.*?)_([a-zA-Z])", lambda m: m.group(1) + m.group(2).upper(), s, 0)
+
+
 def absolutify_m3u8(m3u8_url):
     import m3u8
 
